:root{--vt-c-white: #ffffff;--vt-c-white-soft: #f8f8f8;--vt-c-white-mute: #f2f2f2;--vt-c-black: #181818;--vt-c-black-soft: #222222;--vt-c-black-mute: #282828;--vt-c-indigo: #2c3e50;--vt-c-divider-light-1: rgba(60, 60, 60, .29);--vt-c-divider-light-2: rgba(60, 60, 60, .12);--vt-c-divider-dark-1: rgba(84, 84, 84, .65);--vt-c-divider-dark-2: rgba(84, 84, 84, .48);--vt-c-text-light-1: var(--vt-c-indigo);--vt-c-text-light-2: rgba(60, 60, 60, .66);--vt-c-text-dark-1: var(--vt-c-white);--vt-c-text-dark-2: rgba(235, 235, 235, .64)}:root{--color-background: var(--vt-c-white);--color-background-soft: var(--vt-c-white-soft);--color-background-mute: var(--vt-c-white-mute);--color-border: var(--vt-c-divider-light-2);--color-border-hover: var(--vt-c-divider-light-1);--color-heading: var(--vt-c-text-light-1);--color-text: var(--vt-c-text-light-1);--section-gap: 160px}@media (prefers-color-scheme: dark){:root{--color-background: var(--vt-c-black);--color-background-soft: var(--vt-c-black-soft);--color-background-mute: var(--vt-c-black-mute);--color-border: var(--vt-c-divider-dark-2);--color-border-hover: var(--vt-c-divider-dark-1);--color-heading: var(--vt-c-text-dark-1);--color-text: var(--vt-c-text-dark-2)}}*,*:before,*:after{box-sizing:border-box;margin:0;font-weight:400}body{min-height:100vh;color:var(--color-text);background:var(--color-background);transition:color .5s,background-color .5s;line-height:1.6;font-family:Inter,-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Oxygen,Ubuntu,Cantarell,Fira Sans,Droid Sans,Helvetica Neue,sans-serif;font-size:15px;text-rendering:optimizeLegibility;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale}#app{margin:0 auto;padding:0rem;font-weight:400;overflow:auto}.header{font-size:16px;color:#000}.value{font-size:15px}.comparative-value{font-size:13px}.bg-danger{background-color:red!important}.bg-success{background-color:#03ad00!important}.p-organizationchart-node{min-width:120px}.p-organizationchart-node-selected.bg-success{background-color:#0b270b!important}.p-organizationchart-node-selected.bg-danger{background-color:#270c0c!important}:not(.p-organizationchart-node-selected).bg-success:hover{background-color:#095d07!important}:not(.p-organizationchart-node-selected).bg-danger:hover{background-color:#810404!important}button#save-to-img-btn{color:#232323;background:#f48829;font-family:inherit;padding:.6em 1.3em;font-weight:600;border:3px solid black;border-radius:.4em;box-shadow:.1em .1em #00aeee;cursor:pointer}button#save-to-img-btn:active{color:#000;transform:translate(.05em,.05em);box-shadow:.05em .05em}.err__title[data-v-8a0bf3be],.err__msg[data-v-8a0bf3be],body{margin:0}
